@@ -1,4 +1,5 @@
 /// A way to uniquely identify the location of an object within a pack bundle
+// TODO: this should move to become a pack location, it has nothing to do with an index, it's all about the pack data file
 #[derive(PartialEq, Eq, Debug, Hash, Ord, PartialOrd, Clone)]
 #[cfg_attr(feature = "serde1", derive(serde::Serialize, serde::Deserialize))]
 pub struct Location {
@@ -40,7 +41,7 @@ mod verify {
             &self,
             verify_mode: crate::index::verify::Mode,
             traversal: crate::index::traverse::Algorithm,
-            make_pack_lookup_cache: impl Fn() -> C + Send + Sync,
+            make_pack_lookup_cache: impl Fn() -> C + Send + Clone,
             thread_limit: Option<usize>,
             progress: Option<P>,
             should_interrupt: Arc<AtomicBool>,
