@@ -12,12 +12,10 @@ use crate::{
 
 pub(crate) fn deltas<T, F, P, MBFN, S, E>(
     nodes: crate::cache::delta::Chunk<'_, T>,
-    (bytes_buf, ref mut progress, state): &mut (Vec<u8>, P, S),
-    resolve: F,
-    modify_base: MBFN,
+    (bytes_buf, ref mut progress, state, resolve, modify_base): &mut (Vec<u8>, P, S, F, MBFN),
 ) -> Result<(usize, u64), Error>
 where
-    F: for<'r> Fn(EntryRange, &'r mut Vec<u8>) -> Option<()> + Send + Sync,
+    F: for<'r> Fn(EntryRange, &'r mut Vec<u8>) -> Option<()>,
     P: Progress,
     MBFN: Fn(&mut T, &mut P, Context<'_, S>) -> Result<(), E>,
     T: Default,
