@@ -38,6 +38,7 @@ mod options {
 }
 use std::sync::atomic::Ordering;
 
+use git_features::threading::{lock, Mutable, OwnShared};
 pub use options::Options;
 
 /// Verify and validate the content of the index file
@@ -48,8 +49,8 @@ impl index::File {
     /// For more details, see the documentation on the [`traverse()`][index::File::traverse()] method.
     pub fn traverse_with_lookup<P, C, Processor, E>(
         &self,
-        new_processor: impl Fn() -> Processor + Send + Sync,
-        new_cache: impl Fn() -> C + Send + Sync,
+        new_processor: impl Fn() -> Processor + Send + Clone,
+        new_cache: impl Fn() -> C + Send + Clone,
         mut progress: P,
         pack: &crate::data::File,
         Options {
@@ -96,18 +97,21 @@ impl index::File {
                     parallel::optimize_chunk_size_and_thread_limit(1000, Some(index_entries.len()), thread_limit, None);
                 let there_are_enough_entries_to_process = || index_entries.len() > chunk_size * available_cores;
                 let input_chunks = index_entries.chunks(chunk_size.max(chunk_size));
-                let reduce_progress = parking_lot::Mutex::new({
+                let reduce_progress = OwnShared::new(Mutable::new({
                     let mut p = progress.add_child("Traversing");
                     p.init(Some(self.num_objects() as usize), progress::count("objects"));
                     p
-                });
-                let state_per_thread = |index| {
-                    (
-                        new_cache(),
-                        new_processor(),
-                        Vec::with_capacity(2048), // decode buffer
-                        reduce_progress.lock().add_child(format!("thread {}", index)), // per thread progress
-                    )
+                }));
+                let state_per_thread = {
+                    let reduce_progress = reduce_progress.clone();
+                    move |index| {
+                        (
+                            new_cache(),
+                            new_processor(),
+                            Vec::with_capacity(2048), // decode buffer
+                            lock(&reduce_progress).add_child(format!("thread {}", index)), // per thread progress
+                        )
+                    }
                 };
 
                 in_parallel_if(
@@ -126,7 +130,6 @@ impl index::File {
                             ))),
                         );
                         let mut stats = Vec::with_capacity(entries.len());
-                        let mut header_buf = [0u8; 64];
                         for index_entry in entries.iter() {
                             let result = self.decode_and_process_entry(
                                 check,
@@ -134,7 +137,6 @@ impl index::File {
                                 cache,
                                 buf,
                                 progress,
-                                &mut header_buf,
                                 index_entry,
                                 processor,
                             );
@@ -150,7 +152,7 @@ impl index::File {
                         }
                         Ok(stats)
                     },
-                    Reducer::from_progress(&reduce_progress, pack.data_len(), check, &should_interrupt),
+                    Reducer::from_progress(reduce_progress, pack.data_len(), check, &should_interrupt),
                 )
             },
         );
